![tests status](https://github.com/nikosgavalas/pygav/actions/workflows/main.yml/badge.svg)

Some random python stuff I find useful.

To run tests: Install `pytest` and run `pytest`.

<!-- How to publish this package (notes to my future self):
1. make sure you have `build` and `twine` installed
2. `python -m build`
3. `twine check dist/*`
4. `twine upload -r testpypi dist/*`
5. check everything is fine on testpypi
6. `twine upload dist/*` -->
